﻿using ProjectBattleship.CollectionGenericObjects;
using ProjectBattleship.DrawingObject;
using ProjectBattleship.Exceptions;


namespace Battleship.CollectionGenericObjects;

/// <summary>
/// Параметризованный набор объектов
/// </summary>
/// <typeparam name="T">Параметр: ограничение - ссылочный тип</typeparam>
public class ListGenericObjects<T> : ICollectionGenericObjects<T>
where T : class
{
    /// <summary>
    /// Список объектов, которые храним
    /// </summary>
    private readonly List<T?> _collection;
    /// <summary>
    /// Максимально допустимое число объектов в списке
    /// </summary>
    private int _maxCount;
    public int Count => _collection.Count;

    public int MaxCount
    {
        set
        {
            if (value > 0)
            {
                _maxCount = value;
            }
        }
        get
        {

            return Count;
        }
    }

    public CollectionType GetCollectionType => CollectionType.List;

    /// <summary>
    /// Конструктор
    /// </summary>
    public ListGenericObjects()
    {
        _collection = new();
    }
    public T Get(int position)
    {
        if (position >= Count || position < 0) throw new PositionOutOfCollectionException(position);
        return _collection[position];
    }

    public int Insert(T obj, IEqualityComparer<DrawingWarship?>? comparer = null)
    {
        if (Count == _maxCount) throw new CollectionOverflowException(Count);

        if (comparer != null)
        {
            for (int i = 0; i < Count; i++)
            {
                if (comparer.Equals(_collection[i], obj))
                {
                    throw new CollectionInsertException(obj);
                }
            }
        }

        _collection.Add(obj);
        return Count;
    }

    public int Insert(T obj, int position, IEqualityComparer<DrawingWarship?>? comparer = null)
    {
        if (Count == _maxCount) throw new CollectionOverflowException(Count);
        if (position >= Count || position < 0) throw new PositionOutOfCollectionException(position);

        if (comparer != null)
        {
            for (int i = 0; i < Count; i++)
            {
                if (comparer.Equals(_collection[i], obj))
                {
                    throw new CollectionInsertException(obj);
                }
            }
        }


        _collection.Insert(position, obj);
        return position;
    }

    public T Remove(int position)
    {
        if (position >= _collection.Count || position < 0) throw new PositionOutOfCollectionException(position);
        T obj = _collection[position];
        _collection.RemoveAt(position);
        return obj;
    }

    public IEnumerable<T?> GetItems()
    {
        for (int i = 0; i < Count; ++i)
        {
            yield return _collection[i];
        }
    }

    public void CollectionSort(IComparer<T?> comparer)
    {
        _collection.Sort(comparer);
    }
}