﻿using ProjectBattleship.Entities;
namespace ProjectBattleship.DrawingObject;
/// <summary>
/// Класс, отвечающий за прорисовку и перемещение объекта-сущности
/// </summary>
public class DrawingBattleship : DrawingWarship
{
    public DrawingBattleship(EntityWarship warship) : base(150, 50)
    {
        EntityWarship = warship;
    }


    /// <summary>
    /// Конструктор
    /// </summary>
    /// <param name="speed">Скорость</param>
    /// <param name="weight">Вес</param>
    /// <param name="bodyColor">Основной цвет</param>
    /// <param name="additionalColor">Дополнительный цвет</param>
    /// <param name="turret">Признак наличия обвеса</param>
    /// <param name="rocketCompartment">Признак наличия антикрыла</param>
    public DrawingBattleship(int speed, double weight, Color bodyColor, Color
        additionalColor, bool turret, bool rocketCompartment) : base(150, 50)
    {
        EntityWarship = new EntityBattleship(speed, weight, bodyColor, additionalColor, turret, rocketCompartment);
    }

    public override void DrawTransport(Graphics g)
    {
        if (EntityWarship == null || EntityWarship is not EntityBattleship battleship ||
        !_startPosX.HasValue || !_startPosY.HasValue)
        {
            return;
        }
        Pen pen = new(Color.Black);
        Brush additionalBrush = new SolidBrush(battleship.AdditionalColor);
        base.DrawTransport(g);
        //отсек под ракеты
        if (battleship.RocketCompartment)
        {
            g.FillRectangle(additionalBrush, _startPosX.Value + 14,
                _startPosY.Value + 14, 10, 10);
            g.FillRectangle(additionalBrush, _startPosX.Value + 26,
                _startPosY.Value + 14, 10, 10);
            g.FillRectangle(additionalBrush, _startPosX.Value + 14,
                _startPosY.Value + 26, 10, 10);
            g.FillRectangle(additionalBrush, _startPosX.Value + 26,
                _startPosY.Value + 26, 10, 10);
            g.DrawRectangle(pen, _startPosX.Value + 14,
                _startPosY.Value + 14, 10, 10);
            g.DrawRectangle(pen, _startPosX.Value + 26,
                _startPosY.Value + 14, 10, 10);
            g.DrawRectangle(pen, _startPosX.Value + 14,
                _startPosY.Value + 26, 10, 10);
            g.DrawRectangle(pen, _startPosX.Value + 26,
                _startPosY.Value + 26, 10, 10);
        }
        //орудийная башня
        if (battleship.Turret)
        {
            Point[] turret = new Point[] {new Point(_startPosX.Value + 112,
                _startPosY.Value + 19), new Point(_startPosX.Value + 112,
                _startPosY.Value + 31), new Point(_startPosX.Value + 119,
                _startPosY.Value + 28), new Point(_startPosX.Value + 119,
                _startPosY.Value + 22)};
            g.FillPolygon(additionalBrush, turret);
            g.FillRectangle(additionalBrush, _startPosX.Value + 119,
                _startPosY.Value + 24, 12, 2);
            g.DrawPolygon(pen, turret);
            g.DrawRectangle(pen, _startPosX.Value + 119,
                _startPosY.Value + 24, 12, 2);
        }
    }
}