﻿using ProjectBattleship.Entities;
namespace ProjectBattleship.DrawingObject;
/// <summary>
/// Расширение для класса EntityWarship
/// </summary>
public static class ExtentionDrawingWarship
{
    /// <summary>
    /// Разделитель для записи информации по объекту в файл
    /// </summary>
    private static readonly string _separatorForObject = ":";
    /// <summary>
    /// Создание объекта из строки
    /// </summary>
    /// <param name="info">Строка с данными для создания объекта</param>
    /// <returns>Объект</returns>
    public static DrawingWarship? CreateDrawingWarship(this string info)
    {
        string[] strs = info.Split(_separatorForObject);
        EntityWarship? warship = EntityBattleship.CreateEntityBattleship(strs);
        if (warship != null)
        {
            return new DrawingBattleship(warship);
        }
        warship = EntityWarship.CreateEntityWarship(strs);
        if (warship != null)
        {
            return new DrawingWarship(warship);
        }
        return null;
    }
    /// <summary>
    /// Получение данных для сохранения в файл
    /// </summary>
    /// <param name="drawingWarship">Сохраняемый объект</param>
    /// <returns>Строка с данными по объекту</returns>
    public static string GetDataForSave(this DrawingWarship drawingWarship)
    {
        string[]? array = drawingWarship?.EntityWarship?.GetStringRepresentation();
        if (array == null)
        {
            return string.Empty;
        }
        return string.Join(_separatorForObject, array);
    }
}