﻿using System.Net.Sockets;

namespace ProjectBattleship.Entities;
/// <summary>
/// Класс-сущность "Линкор"
/// </summary>
public class EntityBattleship : EntityWarship
{
    public Color AdditionalColor { get; private set; }
    public void SetAdditionalColor(Color color)
    {
        AdditionalColor = color;
    }
    public bool Turret { get; private set; }
    public bool RocketCompartment { get; private set; }
    public EntityBattleship(int speed, double weight, Color bodyColor, 
        Color additionalColor, bool turret, bool rocketCompartment) : 
        base(speed, weight, bodyColor)
    {
        AdditionalColor = additionalColor;
        Turret = turret;
        RocketCompartment = rocketCompartment;
    }
    /// <summary>
    /// Получение строк со значениями свойств объекта класса-сущности
    /// </summary>
    /// <returns></returns>
    public override string[] GetStringRepresentation()
    {
        return new[] { nameof(EntityBattleship), Speed.ToString(), Weight.ToString(),
            BodyColor.Name, AdditionalColor.Name, RocketCompartment.ToString(), Turret.ToString() };
    }

    /// <summary>
    /// Создание объекта из массива строк
    /// </summary>
    /// <param name="strs"></param>
    /// <returns></returns>
    public static EntityWarship? CreateEntityBattleship(string[] strs)
    {
        if (strs.Length != 7 || strs[0] != nameof(EntityBattleship))
        {
            return null;
        }
        return new EntityBattleship(Convert.ToInt32(strs[1]), Convert.ToDouble(strs[2]), Color.FromName(strs[3]),
            Color.FromName(strs[4]), Convert.ToBoolean(strs[5]), Convert.ToBoolean(strs[6]));
    }
}
