﻿namespace ProjectBattleship.Entities;
/// <summary>
/// Класс-сущность "Военный корабль"
/// </summary>
public class EntityWarship
{
    public int Speed { get; private set; }
    public double Weight { get; private set; }
    public Color BodyColor { get; private set; }
    public void SetBodyColor(Color color)
    {
        BodyColor = color;
    }
    public double Step => Speed * 100 / Weight;
    public EntityWarship(int speed, double weight, Color bodyColor)
    {
        Speed = speed;
        Weight = weight;
        BodyColor = bodyColor;
    }
    /// <summary>
    /// Получение строк со значениями свойств объекта класса-сущности
    /// </summary>
    /// <returns></returns>
    public virtual string[] GetStringRepresentation()
    {
        return new[] { nameof(EntityWarship), Speed.ToString(), 
            Weight.ToString(), BodyColor.Name };
    }
    /// <summary>
    /// Создание объекта из массива строк
    /// </summary>
    /// <param name="strs"></param>
    /// <returns></returns>
    public static EntityWarship? CreateEntityWarship(string[] strs)
    {
        if (strs.Length != 4 || strs[0] != nameof(EntityWarship))
        {
            return null;
        }
        return new EntityWarship(Convert.ToInt32(strs[1]),
            Convert.ToDouble(strs[2]), Color.FromName(strs[3]));
    }
}