﻿using ProjectBattleship.DrawingObject;
using ProjectBattleship.Entities;
namespace ProjectBattleship
{
    /// <summary>
    /// Форма конфигурации объекта
    /// </summary>
    public partial class FormWarshipConfig : Form
    {
        /// <summary>
        /// Объект - прорисовка 
        /// </summary>
        private DrawingWarship? _warship;
        /// <summary>
        /// Событие для передачи объекта
        /// </summary>
        private event Action<DrawingWarship>? WarshipDelegate;
        /// <summary>
        /// Конструктор
        /// </summary>
        public FormWarshipConfig()
        {
            InitializeComponent();
            panelRed.MouseDown += Panel_MouseDown;
            panelGreen.MouseDown += Panel_MouseDown;
            panelBlue.MouseDown += Panel_MouseDown;
            panelYellow.MouseDown += Panel_MouseDown;
            panelWhite.MouseDown += Panel_MouseDown;
            panelGray.MouseDown += Panel_MouseDown;
            panelBlack.MouseDown += Panel_MouseDown;
            panelPurple.MouseDown += Panel_MouseDown;

            buttonCancel.Click += (sender, e) => Close();
        }
        /// <summary>
        /// Привязка внешнего метода к событию
        /// </summary>
        /// <param name="WarshipDelegate"></param>
        public void AddEvent(Action<DrawingWarship> warshipDelegate)
        {
            if (WarshipDelegate != null)
            {
                WarshipDelegate = warshipDelegate;
            }
            else
            {
                WarshipDelegate += warshipDelegate;
            }
        }
        /// <summary>
        /// Прорисовка объекта
        /// </summary>
        private void DrawObject()
        {
            Bitmap bmp = new(pictureBoxObject.Width, pictureBoxObject.Height);
            Graphics gr = Graphics.FromImage(bmp);
            _warship?.SetPictureSize(pictureBoxObject.Width,
            pictureBoxObject.Height);
            _warship?.SetPosition(15, 15);
            _warship?.DrawTransport(gr);
            pictureBoxObject.Image = bmp;
        }
        /// <summary>
        /// Передаем информацию при нажатии на Label
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void LabelObject_MouseDown(object sender, MouseEventArgs e)
        {
            (sender as Label)?.DoDragDrop((sender as Label)?.Name ??
                string.Empty, DragDropEffects.Move | DragDropEffects.Copy);
        }
        /// <summary>
        /// Проверка получаемой информации (ее типа на соответствие требуемому)
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void PanelObject_DragEnter(object sender, DragEventArgs e)
        {
            e.Effect = e.Data?.GetDataPresent(DataFormats.Text) ?? false ?
                DragDropEffects.Copy : DragDropEffects.None;
        }
        /// <summary>
        /// Действия при приеме перетаскиваемой информации
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void PanelObject_DragDrop(object sender, DragEventArgs e)
        {
            switch (e.Data?.GetData(DataFormats.Text)?.ToString())
            {
                case "labelSimpleObject":
                    _warship = new DrawingWarship((int)numericUpDownSpeed.Value,
                        (double)numericUpDownWeight.Value, Color.White);
                    break;
                case "labelModifiedObject":
                    _warship = new
                        DrawingBattleship((int)numericUpDownSpeed.Value,
                        (double)numericUpDownWeight.Value,
                        Color.White, Color.Black, checkBoxTurret.Checked,
                        checkBoxRocketCompartment.Checked);
                    break;
            }
            DrawObject();
        }
        /// <summary>
        /// Передаем информацию при нажатии на Panel
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void Panel_MouseDown(object? sender, MouseEventArgs e)
        {
            (sender as Control)?.DoDragDrop((sender as Control).BackColor, DragDropEffects.Move | DragDropEffects.Copy);

        }

        private void LabelBodyColor_DragEnter(object sender, DragEventArgs e)
        {
            if (e.Data?.GetDataPresent(typeof(Color)) ?? false)
            {
                e.Effect = DragDropEffects.Copy;
            }
            else
            {
                e.Effect = DragDropEffects.None;
            }
        }

        private void LabelBodyColor_DragDrop(object sender, DragEventArgs e)
        {
            if (_warship != null)
            {
                if (e.Data?.GetDataPresent(typeof(Color)) ?? false)
                {
                    _warship.EntityWarship.SetBodyColor((Color)e.Data.GetData(typeof(Color)));
                }
                DrawObject();
            }
        }

        private void LabelAdditionalColor_DragEnter(object sender, DragEventArgs e)
        {
            if (_warship != null && _warship is DrawingBattleship)
            {
                if (e.Data?.GetDataPresent(typeof(Color)) ?? false)
                {
                    e.Effect = DragDropEffects.Copy;
                }
                else
                {
                    e.Effect = DragDropEffects.None;
                }
            }
        }

        private void LabelAdditionalColor_DragDrop(object sender, DragEventArgs e)
        {
            if (_warship != null && _warship.EntityWarship is EntityBattleship _battleship)
            {
                if (e.Data.GetDataPresent(typeof(Color)))
                {
                    _battleship.SetAdditionalColor((Color)e.Data.GetData(typeof(Color)));

                }
                DrawObject();
            }
        }

        private void ButtonAdd_Click(object sender, EventArgs e)
        {
            if (_warship != null)
            {
                WarshipDelegate?.Invoke(_warship);
                Close();
            }
        }
    }
}
